import { __extends } from "tslib";
var DefaultOptions = {
    action: null,
    file: null,
    filename: "file",
    withCredentials: false,
    headers: {},
};
/**
 * 上传文件
 */
export default function upload(options) {
    var opt = Object.assign({}, DefaultOptions, options);
    if (!opt.headers) {
        opt.headers = {};
    }
    var xhr = new XMLHttpRequest();
    // 上传数据
    var formData = new FormData();
    if (opt.data) {
        Object.keys(opt.data).map(function (key) {
            formData.append(key, opt.data[key]);
        });
    }
    formData.append(opt.filename, opt.file);
    xhr.open("post", opt.action, true);
    // 事件
    xhr.onload = function () {
        if (xhr.status < 200 || xhr.status >= 300) {
            return opt.onError(new UploadError("connot upload " + opt.action, opt.action, xhr.status), tryGetResponse(xhr));
        }
        opt.onSuccess(tryGetResponse(xhr), xhr);
    };
    xhr.onerror = function (e) {
        opt.onError(new UploadError("upload fail " + opt.action, opt.action, xhr.status), tryGetResponse(xhr));
    };
    xhr.onabort = function (ev) {
        console.log("上传中断", ev);
    };
    if (opt.onProgress && xhr.upload) {
        xhr.upload.onprogress = function (e) {
            var percent = 0;
            if (e.total > 0) {
                percent = (e.loaded / e.total) * 100;
            }
            options.onProgress(percent, e);
        };
    }
    if (opt.withCredentials && "withCredentials" in xhr) {
        xhr.withCredentials = true;
    }
    // 主动设置 headers['X-Requested-With'] = null, 用于跨域上传
    if (opt.headers["X-Requested-With"] !== null) {
        xhr.setRequestHeader("X-Requested-With", "XMLHttpRequest");
    }
    for (var x in opt.headers) {
        if (opt.headers[x] !== null) {
            xhr.setRequestHeader(x, opt.headers[x]);
        }
    }
    xhr.send(formData);
    return {
        abort: function () {
            // xhr.abort();
        },
    };
}
var UploadError = /** @class */ (function (_super) {
    __extends(UploadError, _super);
    /**
     * 构造函数
     * @param msg
     * @param url
     * @param status
     */
    function UploadError(msg, url, status) {
        var _this = _super.call(this, msg) || this;
        _this.url = url;
        _this.status = status;
        return _this;
    }
    return UploadError;
}(Error));
export { UploadError };
function tryGetResponse(xhr) {
    var text = xhr.responseText || xhr.response;
    if (!text) {
        return text;
    }
    try {
        return JSON.parse(text);
    }
    catch (e) {
        return text;
    }
}
//# sourceMappingURL=HttpUpload.js.map