import { __assign } from "tslib";
import React, { useRef, useState } from "react";
import classNames from "classnames";
import { attrAccept, createUid, getValue } from "./utils";
import traverseFileTree from "./TraverseFileTree";
import httpUpload from "./HttpUpload";
import compress from "./Compress";
var HideStyle = { display: "none" };
function Upload(props) {
    var _a = props.prefixCls, prefixCls = _a === void 0 ? "xy-upload" : _a, className = props.className, directory = props.directory, style = props.style, accept = props.accept, beforeUpload = props.beforeUpload, customRequest = props.customRequest, disabled = props.disabled, _b = props.multiple, multiple = _b === void 0 ? false : _b, _c = props.name, name = _c === void 0 ? "file" : _c, withCredentials = props.withCredentials, headers = props.headers, onStart = props.onStart, onSuccess = props.onSuccess, onError = props.onError, onProgress = props.onProgress, children = props.children, options = props.options;
    var ref = useRef(null);
    // 唯一得 uid，用于重置input.files, 让其触发后续同一文件得onChange事件
    var _d = useState(createUid()), uid = _d[0], setUid = _d[1];
    function uploadFiles(files) {
        if (disabled) {
            return;
        }
        var fileList = [].map.call(files, function (file) {
            file.uid = createUid();
            return file;
        });
        fileList.forEach(function (file) { return upload(file, fileList); });
    }
    function upload(file, fileList) {
        if (!beforeUpload) {
            postFile(file);
        }
        else {
            var pass = beforeUpload(file, fileList);
            var passPromise = pass;
            if (passPromise && passPromise.then) {
                passPromise
                    .then(function (processedFile) {
                    var processedFileType = Object.prototype.toString.call(processedFile);
                    if (processedFileType === "[object File]" || processedFileType === "[object Blob]") {
                        return postFile(processedFile);
                    }
                    return postFile(file);
                })
                    .catch(function (e) {
                    console.log("beforeUpload faild", e);
                });
            }
            else if (pass !== false) {
                postFile(file);
            }
        }
    }
    function postFile(file) {
        var data = getValue(props.data, [file]);
        var action = getValue(props.action, [file]);
        return compress(file, options).then(function (fileUploadRaw) {
            console.log("fileUploadRaw", fileUploadRaw);
            return new Promise(function (resolve, reject) {
                var request = customRequest || httpUpload;
                if (onStart) {
                    onStart(file);
                }
                request({
                    file: fileUploadRaw,
                    data: data,
                    action: action,
                    headers: headers,
                    filename: name,
                    withCredentials: withCredentials,
                    onSuccess: function (response, xhr) {
                        if (onSuccess) {
                            onSuccess(file, response, xhr);
                        }
                        resolve(response);
                    },
                    onError: function (error, response) {
                        if (onError) {
                            onError(file, error, response);
                        }
                        reject(error);
                    },
                    onProgress: function (percent, event) {
                        if (onProgress) {
                            onProgress(file, percent, event);
                        }
                    },
                });
            });
        });
    }
    // function abort(file?: FileExtend) {
    //     const reqs = reqsRef.current;
    //     if (file) {
    //         // 中断单个上传
    //         if (file.uid && reqs.has(file.uid)) {
    //             const res = reqs.get(file.uid);
    //             if (res && res.abort) {
    //                 res.abort();
    //             }
    //         }
    //     } else {
    //         // 中断所有上传
    //         reqs.forEach((res, uid) => {
    //             if (res && res.abort) {
    //                 res.abort();
    //             }
    //         });
    //         reqs.clear();
    //     }
    // }
    function onClick() {
        var input = ref.current;
        if (input) {
            input.click();
        }
    }
    function onChange(e) {
        uploadFiles(e.target.files);
        setUid(createUid());
    }
    function onFileDrop(e) {
        e.preventDefault();
        if (e.type === "dragover") {
            return;
        }
        if (directory) {
            traverseFileTree(e.dataTransfer.items, function (files) { return uploadFiles(files); }, function (_file) { return attrAccept(_file, accept); });
        }
        else {
            var files = Array.prototype.slice.call(e.dataTransfer.files).filter(function (file) { return attrAccept(file, accept); });
            uploadFiles(files);
        }
    }
    function onKeyDown(e) {
        // Enter
        if (e.keyCode === 13) {
            onClick();
        }
    }
    // useUnmount(abort);
    var events = disabled
        ? {}
        : {
            onClick: onClick,
            onKeyDown: onKeyDown,
            onDrop: onFileDrop,
            onDragOver: onFileDrop,
            tabIndex: 0,
        };
    var directoryProps = directory
        ? {
            directory: "directory",
            webkitdirectory: "webkitdirectory",
        }
        : {};
    return (React.createElement("span", __assign({ className: classNames(prefixCls, className), style: style }, events),
        React.createElement("input", __assign({ type: "file", key: uid, ref: ref, style: HideStyle, accept: accept, name: name, onChange: onChange, multiple: multiple }, directoryProps)),
        children));
}
export default React.memo(Upload);
//# sourceMappingURL=Upload.js.map