import { __assign, __rest, __spreadArrays } from "tslib";
import classNames from "classnames";
import React, { useEffect, useRef } from "react";
import { DefineDefaultValue, useForceUpdate } from "utils-hooks";
import { UploadFrame } from ".";
import UploadButton from "./UploadButton";
var UploadList = React.forwardRef(function (props, ref) {
    var _a = props.prefixCls, prefixCls = _a === void 0 ? "upload-list" : _a, className = props.className, style = props.style, _b = props.disabledUpload, disabledUpload = _b === void 0 ? false : _b, _c = props.maxUpload, maxUpload = _c === void 0 ? 10 : _c, value = props.value, defaultValue = props.defaultValue, onChange = props.onChange, icons = props.icons, onView = props.onView, onRemove = props.onRemove, onStart = props.onStart, onSuccess = props.onSuccess, onError = props.onError, onProgress = props.onProgress, rest = __rest(props, ["prefixCls", "className", "style", "disabledUpload", "maxUpload", "value", "defaultValue", "onChange", "icons", "onView", "onRemove", "onStart", "onSuccess", "onError", "onProgress"]);
    var listRef = useRef(DefineDefaultValue(props, "value", "defaultValue") || []);
    var list = listRef.current;
    // const [list, setList] = useState<UploadResult[]>(listRef.current);
    var update = useForceUpdate();
    function changeList(d) {
        listRef.current = d;
        // setList(d);
        update();
        if (onChange) {
            onChange(d);
        }
    }
    useEffect(function () {
        if (value) {
            listRef.current = value;
            // setList(value);
            update();
        }
    }, [value]);
    function onStartHandle(file) {
        var latestList = listRef.current;
        changeList(__spreadArrays(latestList, [{ status: "uploading", file: file, thumbnail: URL.createObjectURL(file), percent: 0 }]));
        if (onStart) {
            onStart(file);
        }
    }
    function onSuccessHandle(file, response, xhr) {
        var latestList = listRef.current;
        var index = latestList.findIndex(function (x) { return x.file.uid === file.uid; });
        if (index !== -1) {
            latestList.splice(index, 1, { file: file, thumbnail: URL.createObjectURL(file), status: "success", percent: 100, response: response });
            changeList(latestList);
        }
        if (onSuccess) {
            onSuccess(file, response, xhr);
        }
    }
    function onErrorHandle(file, response, xhr) {
        var latestList = listRef.current;
        var index = latestList.findIndex(function (x) { return x.file.uid === file.uid; });
        if (index !== -1) {
            latestList[index] = { file: file, thumbnail: URL.createObjectURL(file), status: "error", percent: 100, response: response };
            changeList(latestList);
        }
        if (onError) {
            onError(file, response, xhr);
        }
    }
    function onProgressHandle(file, percent, event) {
        var latestList = listRef.current;
        var index = latestList.findIndex(function (x) { return x.file.uid === file.uid; });
        if (index !== -1) {
            latestList[index] = { file: file, thumbnail: URL.createObjectURL(file), status: "uploading", percent: percent };
            changeList(latestList);
        }
        if (onProgress) {
            onProgress(file, percent, event);
        }
    }
    function onRemoveHandle(result) {
        var latestList = listRef.current;
        var i = latestList.findIndex(function (x) { return x.file.uid === result.file.uid; });
        if (i !== -1) {
            latestList.splice(i, 1);
            changeList(latestList);
        }
        if (onRemove) {
            onRemove(result);
        }
    }
    return (React.createElement("div", { className: classNames(prefixCls, className, { empty: list.length === 0 }), style: style, ref: ref },
        list.map(function (x, i) { return (React.createElement(UploadFrame, { list: list, index: i, key: i, result: x, icons: icons, onView: onView, onRemove: onRemoveHandle, disabledUpload: disabledUpload })); }),
        disabledUpload || list.length >= maxUpload ? null : React.createElement(UploadButton, __assign({ key: "upload-btn" }, rest, { btnMode: true, onStart: onStartHandle, onSuccess: onSuccessHandle, onError: onErrorHandle, onProgress: onProgressHandle }))));
});
export default React.memo(UploadList);
//# sourceMappingURL=UploadList.js.map